@@ -72,6 +72,7 @@ def run_pulls(**kwargs):
 @click.option('-o', '--outname', default='ranking', help='Output file name prefix')
 @click.option('--style', default='default', help='Plotting style. Built-in styles are "default" and "trex".'+\
                                                  'Specify path to yaml file to set custom plotting style.')
+@click.option('--fix_axis_scale/--free_axis_scale', default=True, help='Fix the axis scale across all ranking plots')
 def plot_pulls(**kwargs):
     """
     Tool for plotting NP pulls and impact rankings
@@ -134,6 +135,7 @@ def likelihood_scan(**kwargs):
 @click.option('--CL', 'CL', default=0.95, help='CL value to use')
 @click.option('--precision', default=0.005, help='precision in mu that defines iterative cutoff')
 @click.option('--do_tilde/--no_tilde', default=True, help='bound mu at zero if true and do the \tilde{q}_{mu} asymptotics')
+@click.option('--predictive_fit/--no_predictive_fit', default=True, help='extrapolate best fit nuisance parameters based on previous fit results')
 @click.option('--do_better_bands/--skip_better_bands', default=True, help='evaluate asymptotic CLs limit for various sigma bands')
 @click.option('--better_negative_bands/--skip_better_negative_bands', default=False, 
               help='evaluate asymptotic CLs limit for negative sigma bands')
