@@ -26,7 +26,7 @@ class AsymptoticCLs(AnalysisObject):
     
     def __init__(self, filename:str, poi_name:str=None, data_name:str='combData', 
                  CL:float=0.95, precision:float=0.005, do_tilde:bool=True,
-                 do_better_bands:bool=True, use_predictive_fit:bool=False,
+                 do_better_bands:bool=True, predictive_fit:bool=False,
                  better_negative_bands:bool=False, do_blind:bool=True,
                  binned_likelihood:bool=True, fix_param:str='', profile_param:str='',
                  ws_name:Optional[str]=None, mc_name:Optional[str]=None,
@@ -74,7 +74,7 @@ class AsymptoticCLs(AnalysisObject):
         self.CL = CL
         self.precision = precision
         self.do_tilde = do_tilde
-        self.use_predictive_fit = use_predictive_fit
+        self.use_predictive_fit = predictive_fit
         self.do_better_bands = do_better_bands
         self.better_negative_bands = better_negative_bands
         self.direction = 1
