@@ -144,10 +144,10 @@ class ExtendedModel(object):
         if self.ws_name is None:
             ws_names = [i.GetName() for i in file.GetListOfKeys() if i.GetClassName() == 'RooWorkspace']
             if not ws_names:
-                raise RuntimeError("No workspaces found in the root file: {}".fomat(fname))
+                raise RuntimeError("No workspaces found in the root file: {}".format(self.fname))
             if len(ws_names) > 1:
                 print("WARNING: Found multiple workspace instances from the root file: {}. Available workspaces"
-                      " are \"{}\". Will choose the first one by default".format(fname, ','.join(ws_names)))
+                      " are \"{}\". Will choose the first one by default".format(self.fname, ','.join(ws_names)))
             self.ws_name = ws_names[0]
 
         ws = file.Get(self.ws_name)
@@ -158,7 +158,7 @@ class ExtendedModel(object):
         if self.mc_name is None:
             mc_names = [i.GetName() for i in ws.allGenericObjects() if 'ModelConfig' in i.ClassName()]
             if not mc_names:
-                raise RuntimeError("no ModelConfig object found in the workspace: {}".fomat(ws_name))
+                raise RuntimeError("no ModelConfig object found in the workspace: {}".format(ws_name))
             if len(mc_names) > 1:
                 print("WARNING: Found multiple ModelConfig instances from the workspace: {}. "
                       "Available ModelConfigs are \"{}\". "
@@ -441,9 +441,10 @@ class ExtendedModel(object):
         return self._unfold_constraints(source, self.observables, self.nuisance_parameters, threshold=threshold)
     
     @staticmethod
-    def _pair_nuis_and_glob_obs(constraint_set:ROOT.RooArgSet, globs:ROOT.RooArgSet, nuis:ROOT.RooArgSet):
+    def _pair_constraints(constraint_set:ROOT.RooArgSet, globs:ROOT.RooArgSet, nuis:ROOT.RooArgSet):
         nuis_list = []
         glob_list = []
+        pdf_list = []
         for pdf in constraint_set:
             target_np   = None
             target_glob = None
@@ -477,11 +478,24 @@ class ExtendedModel(object):
                 continue
             nuis_list.append(target_np)
             glob_list.append(target_glob)
-        return nuis_list, glob_list
+            pdf_list.append(pdf)
+        return nuis_list, glob_list, pdf_list
     
     def pair_nuis_and_glob_obs(self):
         constraint_set = self.unfold_constraints()
-        return self._pair_nuis_and_glob_obs(constraint_set, self.global_observables, self.nuisance_parameters)
+        nuis_list, glob_list, _ = self._pair_constraints(constraint_set, self.global_observables, self.nuisance_parameters)
+        return nuis_list, glob_list
+
+    def pair_constraints(self, to_str=False):
+        constraint_set = self.unfold_constraints()
+        nuis_list, glob_list, pdf_list = self._pair_constraints(constraint_set, self.global_observables, self.nuisance_parameters)
+        if to_str:
+            nuis_names = [i.GetName() for i in nuis_list]
+            glob_names = [i.GetName() for i in glob_list]
+            pdf_names  = [i.GetName() for i in pdf_list]
+            size = len(nuis_names)
+            return [(pdf_names[i], nuis_names[i], glob_names[i]) for i in range(size)]
+        return nuis_list, glob_list, pdf_list 
     
     def get_all_constraints(self):
         all_constraints = ROOT.RooArgSet()
@@ -647,6 +661,7 @@ class ExtendedModel(object):
         obs = pdf.getObservables(self.observables)        
         target_obs = obs.first()
         expected_events = pdf.expectedEvents(obs)
+        #print("INFO: Generating Asimov for pdf {}".format(pdf.GetName()))
         for i in range(target_obs.numBins()):
             target_obs.setBin(i)
             norm = pdf.getVal(obs)*target_obs.getBinWidth(i)
@@ -692,10 +707,10 @@ class ExtendedModel(object):
         ws.saveSnapshot(tmp_nuis_name, nuis)
         if not ws.getSnapshot(nom_glob_name):
             print('INFO: Saving snapshot "{}"'.format(nom_glob_name))
-            ws.saveSnapshot("nominalGlobs", globs)
+            ws.saveSnapshot(nom_glob_name, globs)
         if not ws.getSnapshot(nom_nuis_name):
             print('INFO: Saving snapshot "{}"'.format(nom_nuis_name))
-            ws.saveSnapshot("nominalNuis", nuis)
+            ws.saveSnapshot(nom_nuis_name, nuis)
 
         if do_conditional and (poi_profile is not None):
             from quickstats.components import ExtendedMinimizer
@@ -715,7 +730,7 @@ class ExtendedModel(object):
         poi.setVal(poi_val)
         poi.setConstant(0)
 
-        for np, glob in zip(nuis_list, glob_list):        
+        for np, glob in zip(nuis_list, glob_list):
             glob.setVal(np.getVal())
 
         if do_conditional and (poi_profile is not None):
@@ -760,7 +775,7 @@ class ExtendedModel(object):
     def to_dataframe(args):
         import pandas as pd
         data = [{'Name':i.GetName(), 'Value':i.getVal(), "Constant":i.isConstant(), "Min":i.getMin(), "Max":i.getMax()} for i in args]
-        df = pandas.DataFrame(data)
+        df = pd.DataFrame(data)
         return df
     
     @staticmethod
@@ -774,7 +789,7 @@ class ExtendedModel(object):
         if ws_name is None:
             ws_names = [i.GetName() for i in file.GetListOfKeys() if i.GetClassName() == 'RooWorkspace']
             if not ws_names:
-                raise RuntimeError("No workspaces found in the root file: {}".fomat(fname))
+                raise RuntimeError("No workspaces found in the root file: {}".format(fname))
             if len(ws_names) > 1:
                 print("WARNING: Found multiple workspace instances from the root file: {}. Available workspaces"
                       " are \"{}\". Will choose the first one by default".format(fname, ','.join(ws_names)))
@@ -786,7 +801,7 @@ class ExtendedModel(object):
         if mc_name is None:
             mc_names = [i.GetName() for i in ws.allGenericObjects() if 'ModelConfig' in i.ClassName()]
             if not mc_names:
-                raise RuntimeError("no ModelConfig object found in the workspace: {}".fomat(ws_name))
+                raise RuntimeError("no ModelConfig object found in the workspace: {}".format(ws_name))
             if len(mc_names) > 1:
                 print("WARNING: Found multiple ModelConfig instances from the workspace: {}. "
                       "Available ModelConfigs are \"{}\". "
