@@ -35,4 +35,23 @@ def reverse_arrays(*arrays):
         arr[:] = arr[::-1] 
         
 def ceildiv(a, b):
-    return -(-a // b)
\ No newline at end of file
+    return -(-a // b)
+
+def approx_n_digit(val:float, default=5):
+    s = str(val)
+    if not s.replace('.','',1).isdigit():
+        return default
+    elif '.' in s:
+        return len(s.split('.')[1])
+    else:
+        return 0
+
+def str_encode_value(val:float, n_digit=1):
+    val_str = '{{:.{}f}}'.format(n_digit).format(val)  
+    val_str = val_str.replace('.', 'p').replace('-', 'n')
+    return val_str
+
+def str_decode_value(val_str:str):
+    val = float(val_str.replace('p','.').replace('n','-'))
+    return val
+    
\ No newline at end of file
