@@ -186,12 +186,13 @@ class NPRankingPlot:
         input_files = glob.glob(os.path.join(input_dir, "*.json"))
         data = parallel_run(NPRankingPlot._extract_pull_result, input_files, repeat(poi))
         df = pd.DataFrame(data)
-        df['impact_postfit_up']   -= df['poi_hat']
-        df['impact_postfit_down'] -= df['poi_hat']
-        df['impact_prefit_up']    -= df['poi_hat']
-        df['impact_prefit_down']  -= df['poi_hat']
-        df['impact_postfit_total'] = abs(df['impact_postfit_up']) + abs(df['impact_postfit_down'])
-        df['impact_prefit_total']  = abs(df['impact_prefit_up']) + abs(df['impact_prefit_down'])
+        if poi:
+            df['impact_postfit_up']   -= df['poi_hat']
+            df['impact_postfit_down'] -= df['poi_hat']
+            df['impact_prefit_up']    -= df['poi_hat']
+            df['impact_prefit_down']  -= df['poi_hat']
+            df['impact_postfit_total'] = abs(df['impact_postfit_up']) + abs(df['impact_postfit_down'])
+            df['impact_prefit_total']  = abs(df['impact_prefit_up']) + abs(df['impact_prefit_down'])
         return df
     
     def load(self, input_dir:str, poi:Optional[str]=None):
@@ -200,10 +201,11 @@ class NPRankingPlot:
     @staticmethod
     def get_processed_data(df, num=None, threshold=None, ranking=True):
         processed_df = df.copy()
-        if ranking:
-            processed_df.sort_values('impact_postfit_total', ascending=False, inplace=True)
-        if threshold is not None:
-            processed_df = processed_df[processed_df['impact_postfit_total'] >= threshold]            
+        if 'impact_postfit_total' in processed_df:
+            if ranking:
+                processed_df.sort_values('impact_postfit_total', ascending=False, inplace=True)
+            if threshold is not None:
+                processed_df = processed_df[processed_df['impact_postfit_total'] >= threshold]            
         if num is not None:
             processed_df = processed_df.head(num)
         processed_df = processed_df.iloc[::-1]
@@ -505,7 +507,7 @@ class NPRankingPlot:
               sigma_lines:bool=True, shade:bool=True, correlation:bool=True, onesided:bool=True, theta_max:float=2, 
               padding:int=7, height:float=1, spacing:float=0, display_poi:str=r"$\mu$", extra_text:str=None, 
               elumi_label:bool=True, ranking_label:bool=True, energy:float=13, lumi:float=139,
-              n_rank=None, rank_per_plot=20, combine_pdf=True, threshold=0, ranking=True,
+              n_rank=None, rank_per_plot=20, combine_pdf=True, threshold=0, ranking=True, fix_axis_scale=True,
               outdir="ranking_plots", outname:str='ranking', style:Union[str, Dict]=DEFAULT_STYLE):
         if isinstance(style, str):
             style = self.parse_style(style)
@@ -513,7 +515,7 @@ class NPRankingPlot:
             raise ValueError("no data to process")
         has_impact = any('impact' in i for i in self.data)
         if not has_impact:
-            ranking, threshold, show_prefit, show_postfit = False
+            ranking, threshold, show_prefit, show_postfit = False, False, False, False
         processed_data = self.get_processed_data(self.data, num=n_rank, threshold=threshold, ranking=ranking)
         num_data = len(processed_data)
         if not num_data:
@@ -525,6 +527,7 @@ class NPRankingPlot:
         if combine_pdf:
             pdf_name = os.path.join(outdir, '{}_rank_{:04d}_to_{:04d}.pdf'.format(outname, 1, num_data))
             pp = PdfPages(pdf_name)
+        nominal_xlim = None
         for i in range(n_plot):
             start, end = rank_per_plot*i, rank_per_plot*(i+1)
             data_slice = processed_data[::-1][start:end][::-1]
@@ -533,6 +536,11 @@ class NPRankingPlot:
                              onesided=onesided, theta_max=theta_max, padding=padding, height=height, spacing=spacing,
                              display_poi=display_poi, extra_text=extra_text, elumi_label=elumi_label,
                              ranking_label=ranking_label, energy=energy, lumi=lumi, r_start=start+1, style=style)
+            if fix_axis_scale:
+                if nominal_xlim is None:
+                    nominal_xlim = fig.get_axes()[1].get_xlim()
+                else:
+                    fig.get_axes()[1].set_xlim(nominal_xlim)
             base_name = os.path.join(outdir, '{}_rank_{:04d}_to_{:04d}'.format(outname, start+1, start+len(data_slice)))
             fig.savefig(base_name+'.eps', bbox_inches='tight')
             fig.savefig(base_name+'.png', dpi=dpi, bbox_inches='tight')
